@@ -8,7 +8,7 @@ from .icons import (
     icon_import_setup_action_list,
     icon_import_setup_action_backend_selection,
     icon_import_setup_backend_selection, icon_import_setup_delete,
-    icon_import_setup_edit, icon_import_setup_process,
+    icon_import_setup_edit, icon_import_setup_log_list, icon_import_setup_process,
     icon_import_setup_item_delete, icon_import_setup_item_document_list,
     icon_import_setup_item_process, icon_import_setup_clear,
     icon_import_setup_items_list, icon_import_setup_list,
@@ -51,6 +51,11 @@ link_import_setup_list = Link(
     text=_('Import setup list'),
     view='importer:import_setup_list'
 )
+link_import_setup_logs = Link(
+    args=('resolved_object.pk',), icon_class=icon_import_setup_log_list,
+    permissions=(permission_import_setup_view,), text=_('Logs'),
+    view='importer:import_setup_log_list'
+)
 link_import_setup_setup = Link(
     condition=get_cascade_condition(
         app_label='importer', model_name='ImportSetup',
