@@ -25,7 +25,7 @@ from .forms import (
 )
 from .icons import (
     icon_import_setup_action, icon_import_setup_items_list,
-    icon_import_setup_list
+    icon_import_setup_list, icon_import_setup_log_list
 )
 from .links import (
     link_import_setup_action_backend_selection, link_import_setup_backend_selection,
@@ -411,6 +411,14 @@ class ImportSetupPopulateView(MultipleObjectConfirmActionView):
         queryset = self.object_list
 
         result = {
+            'message': _(
+                'This process will run in the background. Depending on the '
+                'number of files that match the import setup criteria, '
+                'the import backend, the size of the source repository, '
+                'and the bandwidth between Mayan EDMS and the source '
+                'repository, it may take between a few minutes to a few '
+                'days for the entire population process to complete.'
+            ),
             'title': ungettext(
                 singular='Populate the selected import setup?',
                 plural='Populate the selected import setups?',
@@ -746,3 +754,29 @@ class ImportSetupItemSaveDownloadView(SingleObjectDownloadView):
 
     def get_download_filename(self):
         return '{}.csv'.format(self.object)
+
+
+class ImportSetupLogListView(ExternalObjectMixin, SingleObjectListView):
+    external_object_class = ImportSetup
+    external_object_permission = permission_import_setup_view
+    external_object_pk_url_kwarg = 'import_setup_id'
+
+    def get_extra_context(self):
+        return {
+            'hide_object': True,
+            'no_results_icon': icon_import_setup_log_list,
+            'no_results_text': _(
+                'This view displays the error log for import setups. '
+                'An empty list is a good thing.'
+            ),
+            'no_results_title': _(
+                'There are no error log entries'
+            ),
+            'object': self.external_object,
+            'title': _(
+                'Log entries for import setup: %s'
+            ) % self.external_object,
+        }
+
+    def get_source_queryset(self):
+        return self.external_object.logs.all()
